@@ -1,7 +1,9 @@
 import os
+from .util import adapt_linesep
 
 ITEM = ('alias', 'options')
 
+
 def parse_item(content, item):
     if item == 'alias':
         return parse_alias(content)
@@ -20,12 +22,7 @@ def parse_comment(doc):
         'alias': None
     }
 
-    if '\r\n' in doc:
-        nl = '\r\n'
-    elif '\n' in doc:
-        nl = '\n'
-    else:
-        nl = os.linesep
+    nl = adapt_linesep(doc)
 
     lines = doc.split(nl)
     for line in lines:
