@@ -1,4 +1,4 @@
-import os
+from .util import adapt_linesep
 
 __all__ = [
     'Color', 'output', 'output_comment',
@@ -30,7 +30,7 @@ class Color:
     BG_WHITE = 47
 
 
-def output(content, background=0, color=Color.WHITE, *args, **kwargs):
+def output(content, background=0, color=0, *args, **kwargs):
     print(__OUTPUT_STR.format(
         background=background,
         color=color,
@@ -38,12 +38,14 @@ def output(content, background=0, color=Color.WHITE, *args, **kwargs):
     ), *args, **kwargs)
 
 
-def output_comment(content, background=0, color=Color.WHITE, *args, **kwargs):
+def output_comment(content, background=0, color=0, *args, **kwargs):
     msg = ''
-    content = content.strip(os.linesep)
+
+    nl = adapt_linesep(content)
+    content = content.strip(nl)
 
     indent_space = 0
-    for i, v in enumerate(content.split(os.linesep)):
+    for i, v in enumerate(content.split(nl)):
         if i == 0:
             for index, char in enumerate(v):
                 if char != ' ':
@@ -51,11 +53,11 @@ def output_comment(content, background=0, color=Color.WHITE, *args, **kwargs):
                     break
         # Eliminate spaces
         line = v[indent_space:]
-        msg += f'{line}{os.linesep}'
+        msg += f'{line}{nl}'
 
     # output
     print(__OUTPUT_STR.format(
         background=background,
         color=color,
-        content=msg,
+        content=msg.strip(nl),
     ), *args, **kwargs)
